@@ -1,8 +1,8 @@
 /* Pioneers - Implementation of the excellent Settlers of Catan board game.
  *   Go buy a copy.
  *
- * Copyright (C) 1999 the Free Software Foundation
- * Copyright (C) 2003 Bas Wijnen <b.wijnen@phys.rug.nl>
+ * Copyright (C) 1999 Dave Cole
+ * Copyright (C) 2003 Bas Wijnen <shevek@fmf.nl>
  * Copyright (C) 2005 Roland Clobus <rclobus@bigfoot.com>
  * 
  * This program is free software; you can redistribute it and/or modify
@@ -17,7 +17,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 #include "config.h"
@@ -1060,11 +1060,11 @@ static gboolean will_do_maritime_trade(gint assets[NO_RESOURCE],
 	 * We can trade, but we won't be able to buy anything.
 	 *
 	 * Try a simple heuristic - if there's a resource we can trade away
-	 * and still have at least 1 left, and we need something, do the
-	 * trade.  Try to use the best port for this.
+	 * and still have at least 1 left, and we need something (and we can
+	 * get it), do the trade.  Try to use the best port for this.
 	 */
 	want = resource_desire(assets, resval);
-	if (want == NO_RESOURCE)
+	if (want == NO_RESOURCE || get_bank()[want] == 0)
 		return FALSE;
 
 	discard = NO_RESOURCE;
@@ -1358,9 +1358,8 @@ static float score_hex_hurt_opponents(Hex * hex)
 	if (hex == NULL)
 		return -1000;
 
-	/* secord arg in can_robber_or_pirate_be_moved is not used.
-	   don't move the pirate. */
-	if (!can_robber_or_pirate_be_moved(hex, 0)
+	/* don't move the pirate. */
+	if (!can_robber_or_pirate_be_moved(hex)
 	    || hex->terrain == SEA_TERRAIN)
 		return -1000;
 
@@ -1460,7 +1459,7 @@ static void greedy_free_road(void)
  * We played a year of plenty card. pick the two resources we most need
  */
 
-static void greedy_year_of_plenty(gint bank[NO_RESOURCE])
+static void greedy_year_of_plenty(const gint bank[NO_RESOURCE])
 {
 	gint want[NO_RESOURCE];
 	gint assets[NO_RESOURCE];
@@ -1835,7 +1834,7 @@ static void greedy_discard_add(gint player_num, gint discard_num)
 	}
 }
 
-static void greedy_gold_choose(gint gold_num, gint * bank)
+static void greedy_gold_choose(gint gold_num, const gint * bank)
 {
 	resource_values_t resval;
 	gint assets[NO_RESOURCE];
