@@ -1,7 +1,7 @@
 /* Pioneers - Implementation of the excellent Settlers of Catan board game.
  *   Go buy a copy.
  *
- * Copyright (C) 2003 Bas Wijnen <b.wijnen@phys.rug.nl>
+ * Copyright (C) 2003 Bas Wijnen <shevek@fmf.nl>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -15,7 +15,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 #include "config.h"
@@ -173,7 +173,6 @@ void cb_domestic(gint * supply, gint * receive)
 	sm_send(SM(), "domestic-trade call supply %R receive %R\n",
 		supply, receive);
 	if (callback_mode == MODE_DOMESTIC) {
-		printf("call again\n");
 		sm_push(SM(), mode_trade_call_again_response);
 	} else {
 		sm_push(SM(), mode_trade_call_response);
@@ -500,7 +499,7 @@ int robber_count_victims(const Hex * hex, gint * victim_list)
 	/* If there is no-one to steal from, or the players have no
 	 * resources, we do not go into steal_resource.
 	 */
-	for (idx = 0; idx < num_players(); idx++)
+	for (idx = 0; idx < G_N_ELEMENTS(hex->nodes); idx++)
 		victim_list[idx] = -1;
 	num_victims = 0;
 	for (node_idx = 0; node_idx < G_N_ELEMENTS(hex->nodes); node_idx++) {
