@@ -1,7 +1,7 @@
 /* Pioneers - Implementation of the excellent Settlers of Catan board game.
  *   Go buy a copy.
  *
- * Copyright (C) 1999 the Free Software Foundation
+ * Copyright (C) 1999 Dave Cole
  * Copyright (C) 2003-2005 Bas Wijnen <shevek@fmf.nl>
  * 
  * This program is free software; you can redistribute it and/or modify
@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 #include "config.h"
@@ -149,7 +149,7 @@ static void dummy_gold_remove(G_GNUC_UNUSED gint player_num,
 {;
 }
 static void dummy_gold_choose(G_GNUC_UNUSED gint gold_num,
-			      G_GNUC_UNUSED gint * bank)
+			      G_GNUC_UNUSED const gint * bank)
 {;
 }
 static void dummy_gold_done(void)
@@ -180,7 +180,7 @@ static void dummy_roadbuilding(G_GNUC_UNUSED gint num_roads)
 static void dummy_monopoly(void)
 {;
 }
-static void dummy_plenty(G_GNUC_UNUSED gint * bank)
+static void dummy_plenty(G_GNUC_UNUSED const gint * bank)
 {;
 }
 static void dummy_turn(void)
@@ -1141,8 +1141,6 @@ gboolean mode_build_response(StateMachine * sm, gint event)
 	BuildType build_type;
 	gint x, y, pos;
 
-	g_print("Mode_build_response\n");
-	sm_stack_dump(sm);
 	sm_state_name(sm, "mode_build_response");
 	switch (event) {
 	case SM_ENTER:
@@ -1480,7 +1478,8 @@ static gboolean mode_road_building(StateMachine * sm, gint event)
 		/* Now determine the amount of segments left to play */
 		build_amount = MIN(build_amount, 2 - build_count_edges());
 		callbacks.roadbuilding(build_amount);
-                callbacks.instructions(road_building_message(build_amount));
+		callbacks.
+		    instructions(road_building_message(build_amount));
 		break;
 	case SM_RECV:
 		if (check_other_players(sm))
