@@ -1,7 +1,7 @@
 /* Pioneers - Implementation of the excellent Settlers of Catan board game.
  *   Go buy a copy.
  *
- * Copyright (C) 2003 Bas Wijnen <b.wijnen@phys.rug.nl>
+ * Copyright (C) 2003 Bas Wijnen <shevek@fmf.nl>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -15,7 +15,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 #include "config.h"
@@ -44,7 +44,7 @@ static void frontend_init_game(void)
 {
 	player_clear_summary();
 	develop_reset();
-	histogram_init();
+	histogram_reset();
 	gui_reset();
 }
 
@@ -96,7 +96,7 @@ static void frontend_robber_moved(G_GNUC_UNUSED Hex * old,
 	gui_prompt_hide();
 }
 
-static void frontend_new_bank(const gint * new_bank)
+static void frontend_new_bank(G_GNUC_UNUSED const gint * new_bank)
 {
 #ifdef DEBUG
 	debug("New bank: %d %d %d %d %d\n", new_bank[0], new_bank[1],
