@@ -1,8 +1,8 @@
 /* Pioneers - Implementation of the excellent Settlers of Catan board game.
  *   Go buy a copy.
  *
- * Copyright (C) 1999 the Free Software Foundation
- * Copyright (C) 2003 Bas Wijnen <b.wijnen@phys.rug.nl>
+ * Copyright (C) 1999 Dave Cole
+ * Copyright (C) 2003 Bas Wijnen <shevek@fmf.nl>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,14 +16,12 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 #include "config.h"
 #include "frontend.h"
 
-#define MAX_CHAT 512		/* maximum chat message size */
-
 static GtkWidget *chat_entry;	/* messages text widget */
 static gboolean chat_grab_focus_on_update = FALSE; /**< Flag to indicate 
  * whether the chat widget should grab the focus whenever a GUI_UPDATE is sent */
@@ -34,7 +32,7 @@ static void chat_cb(GtkEntry * entry, G_GNUC_UNUSED gpointer user_data)
 	const gchar *text = gtk_entry_get_text(entry);
 
 	if (text[0] != '\0') {
-		gchar buff[MAX_CHAT];
+		gchar buff[MAX_CHAT + 1];
 		gint idx;
 
 		strncpy(buff, text, sizeof(buff) - 1);
