@@ -1,8 +1,8 @@
 /* Pioneers - Implementation of the excellent Settlers of Catan board game.
  *   Go buy a copy.
  *
- * Copyright (C) 1999 the Free Software Foundation
- * Copyright (C) 2003 Bas Wijnen <b.wijnen@phys.rug.nl>
+ * Copyright (C) 1999 Dave Cole
+ * Copyright (C) 2003 Bas Wijnen <shevek@fmf.nl>
  * Copyright (C) 2004 Roland Clobus <rclobus@bigfoot.com>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -17,13 +17,12 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 #include "config.h"
 #include <ctype.h>
 #include <stdlib.h>
-#include <unistd.h>		/* For usleep */
 #include <errno.h>
 #include <fcntl.h>
 
@@ -320,7 +319,7 @@ static void meta_create_notify(NetEvent event,
 					    connect_server, connect_port);
 				/* The meta server is now busy creating the new game.
 				 * UGLY FIX: Wait for some time */
-				usleep(500000);
+				g_usleep(500000);
 				connect_close_all(TRUE);
 			} else
 				log_message(MSG_ERROR,
@@ -694,7 +693,7 @@ static void launch_server_gtk(G_GNUC_UNUSED GtkWidget * widget,
 	gchar *child_argv[3];
 	GSpawnFlags flags = G_SPAWN_STDOUT_TO_DEV_NULL |
 	    G_SPAWN_STDERR_TO_DEV_NULL;
-	GError *error;
+	GError *error = NULL;
 	gint i;
 
 	child_argv[0] = g_strdup(PIONEERS_SERVER_GTK_PATH);
@@ -800,6 +799,7 @@ static void meta_dlg_cb(GtkDialog * dlg, gint arg1,
 			connect_set_field(&connect_port, port);
 			g_free(host);
 			g_free(port);
+			gtk_tree_path_free(path);
 			connect_close_all(TRUE);
 		}
 		break;
@@ -1123,7 +1123,7 @@ void connect_create_dlg(void)
 	gtk_misc_set_alignment(GTK_MISC(lbl), 0, 0.5);
 
 	name_entry = gtk_entry_new();
-	gtk_entry_set_max_length(GTK_ENTRY(name_entry), 30);
+	gtk_entry_set_max_length(GTK_ENTRY(name_entry), MAX_NAME_LENGTH);
 	gtk_widget_show(name_entry);
 	gtk_entry_set_text(GTK_ENTRY(name_entry), saved_name);
 	connect_set_field(&connect_name, saved_name);
