@@ -1,8 +1,8 @@
 /* Pioneers - Implementation of the excellent Settlers of Catan board game.
  *   Go buy a copy.
  *
- * Copyright (C) 1999 the Free Software Foundation
- * Copyright (C) 2003 Bas Wijnen <b.wijnen@phys.rug.nl>
+ * Copyright (C) 1999 Dave Cole
+ * Copyright (C) 2003 Bas Wijnen <shevek@fmf.nl>
  * Copyright (C) 2004 Roland Clobus <rclobus@bigfoot.com>
  * 
  * This program is free software; you can redistribute it and/or modify
@@ -17,12 +17,13 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 #include "config.h"
 #include "frontend.h"
 #include "resource-table.h"
+#include "gtkbugs.h"
 
 enum {
 	GOLD_COLUMN_PLAYER_ICON, /**< Player icon */
@@ -64,7 +65,13 @@ gint *choose_gold_get_list(gint * choice)
 	return choice;
 }
 
-void gold_choose_player_must(gint num, gint * bank)
+static void button_destroyed(G_GNUC_UNUSED GtkWidget * w, gpointer num)
+{
+	if (callback_mode == MODE_GOLD)
+		gold_choose_player_must(GPOINTER_TO_INT(num), get_bank());
+}
+
+void gold_choose_player_must(gint num, const gint * bank)
 {
 	GtkWidget *dlg_vbox;
 	GtkWidget *vbox;
@@ -111,6 +118,13 @@ void gold_choose_player_must(gint num, gint * bank)
 	frontend_gui_register(gui_get_dialog_button
 			      (GTK_DIALOG(gold.dlg), 0), GUI_CHOOSE_GOLD,
 			      "clicked");
+	/* This _must_ be after frontend_gui_register, otherwise the
+	 * regeneration of the button happens before the destruction, which
+	 * results in an incorrectly sensitive OK button. */
+	g_signal_connect(gui_get_dialog_button(GTK_DIALOG(gold.dlg), 0),
+			 "destroy", G_CALLBACK(button_destroyed),
+			 GINT_TO_POINTER(num));
+	frontend_gui_update();
 	gtk_widget_show(gold.dlg);
 }
 
@@ -252,6 +266,7 @@ GtkWidget *gold_build_page()
 							  NULL);
 	gtk_tree_view_column_set_sizing(column,
 					GTK_TREE_VIEW_COLUMN_GROW_ONLY);
+	set_pixbuf_tree_view_column_autogrow(gold_widget, column);
 	gtk_tree_view_append_column(GTK_TREE_VIEW(gold_widget), column);
 
 	column = gtk_tree_view_column_new_with_attributes("",
