@@ -1,8 +1,8 @@
 /* Pioneers - Implementation of the excellent Settlers of Catan board game.
  *   Go buy a copy.
  *
- * Copyright (C) 1999 the Free Software Foundation
- * Copyright (C) 2003 Bas Wijnen <b.wijnen@phys.rug.nl>
+ * Copyright (C) 1999 Dave Cole
+ * Copyright (C) 2003 Bas Wijnen <shevek@fmf.nl>
  * Copyright (C) 2004-2005 Roland Clobus <rclobus@bigfoot.com>
  * 
  * This program is free software; you can redistribute it and/or modify
@@ -17,14 +17,16 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 #include "config.h"
 #include <math.h>
 #include <ctype.h>
 #include <assert.h>
+#ifdef HAVE_HELP
 #include <libgnome/libgnome.h>
+#endif
 
 #include "aboutbox.h"
 #include "frontend.h"
@@ -42,7 +44,7 @@ GtkWidget *app_window;		/* main application window */
 #define MAP_WIDTH 550		/* default map width */
 #define MAP_HEIGHT 400		/* default map height */
 
-#define PIONEERS_ICON_FILE	"gnome-pioneers.png"
+#define PIONEERS_ICON_FILE	"pioneers.png"
 
 static GuiMap *gmap;		/* handle to map drawing code */
 
@@ -74,16 +76,7 @@ static GtkWidget *toolbar = NULL;	/* The toolbar */
 
 static gboolean toolbar_show_accelerators = TRUE;
 
-#define PIONEERS_PIXMAP_DICE "pioneers/dice.png"
-#define PIONEERS_PIXMAP_TRADE "pioneers/trade.png"
-#define PIONEERS_PIXMAP_ROAD "pioneers/road.png"
-#define PIONEERS_PIXMAP_SHIP "pioneers/ship.png"
-#define PIONEERS_PIXMAP_SHIP_MOVEMENT "pioneers/ship_move.png"
-#define PIONEERS_PIXMAP_BRIDGE "pioneers/bridge.png"
-#define PIONEERS_PIXMAP_SETTLEMENT "pioneers/settlement.png"
-#define PIONEERS_PIXMAP_CITY "pioneers/city.png"
-#define PIONEERS_PIXMAP_DEVELOP "pioneers/develop.png"
-#define PIONEERS_PIXMAP_FINISH "pioneers/finish.png"
+static GList *rules_callback_list = NULL;
 
 #define PIONEERS_PIXMAP_SPLASH "pioneers/splash.png"
 
@@ -185,7 +178,9 @@ static void help_about_cb(void);
 static void help_legend_cb(void);
 static void help_histogram_cb(void);
 static void help_settings_cb(void);
+#ifdef HAVE_HELP
 static void help_manual_cb(void);
+#endif
 
 /* Normal items */
 static GtkActionEntry entries[] = {
@@ -238,8 +233,10 @@ static GtkActionEntry entries[] = {
 	 NULL, N_("Histogram of dice rolls"), help_histogram_cb},
 	{"HelpAbout", NULL, N_("_About Pioneers"), NULL,
 	 N_("Information about Pioneers"), help_about_cb},
+#ifdef HAVE_HELP
 	{"HelpManual", GTK_STOCK_HELP, N_("_Help"), "<control>H",
 	 N_("Show the manual"), help_manual_cb}
+#endif
 };
 
 /* Toggle items */
@@ -287,7 +284,9 @@ static const char *ui_description =
 "      <menuitem action='DiceHistogram'/>"
 "      <separator/>"
 "      <menuitem action='HelpAbout'/>"
+#ifdef HAVE_HELP
 "      <menuitem action='HelpManual'/>"
+#endif
 "    </menu>"
 "  </menubar>"
 "  <toolbar name='MainToolbar'>"
@@ -469,6 +468,14 @@ void gui_show_quote_page(gboolean show)
 		gtk_widget_hide(quote_page);
 }
 
+static void gui_theme_changed(void)
+{
+	g_assert(legend_page != NULL);
+	gtk_widget_queue_draw(legend_page);
+	gtk_widget_queue_draw_area(gmap->area, 0, 0, gmap->width,
+				   gmap->height);
+}
+
 void gui_show_legend_page(gboolean show)
 {
 	if (show) {
@@ -551,6 +558,7 @@ static GtkWidget *build_map_panel(void)
 				 legend_page, lbl, LEGEND_PAGE);
 	if (!legend_page_enabled)
 		gui_show_legend_page(FALSE);
+	theme_register_callback(G_CALLBACK(gui_theme_changed));
 
 	/* Tab page name, shown for the splash screen */
 	lbl = gtk_label_new(_("Welcome to Pioneers"));
@@ -686,9 +694,6 @@ static void theme_change_cb(GtkWidget * widget, G_GNUC_UNUSED void *data)
 			gmap->pixmap = NULL;
 		}
 		theme_rescale(2 * gmap->x_point);
-		gtk_widget_queue_draw_area(gmap->area, 0, 0, gmap->width,
-					   gmap->height);
-		gtk_widget_queue_draw(legend_page);
 	}
 
 }
@@ -912,10 +917,12 @@ static void help_settings_cb(void)
 	settings_create_dlg();
 }
 
+#ifdef HAVE_HELP
 static void help_manual_cb(void)
 {
 	gnome_help_display("pioneers", NULL, NULL);
 }
+#endif
 
 static GtkAction *getAction(GuiEvent id)
 {
@@ -1097,8 +1104,16 @@ static void gui_toolbar_show_button(const gchar * path, gboolean visible)
 	g_free(fullpath);
 }
 
+void gui_rules_register_callback(GCallback callback)
+{
+	rules_callback_list = g_list_append(rules_callback_list, callback);
+}
+
 void gui_set_game_params(const GameParams * params)
 {
+	GList *list;
+	GtkWidget *label;
+
 	gmap->map = params->map;
 	gmap->player_num = my_player_num();
 	gtk_widget_queue_resize(gmap->area);
@@ -1118,6 +1133,23 @@ void gui_set_game_params(const GameParams * params)
 	identity_draw();
 
 	gui_set_vp_target_value(params->victory_points);
+
+	list = rules_callback_list;
+	while (list) {
+		G_CALLBACK(list->data) ();
+		list = g_list_next(list);
+	}
+
+	label =
+	    gtk_notebook_get_tab_label(GTK_NOTEBOOK(map_notebook),
+				       legend_page);
+	g_object_ref(label);
+
+	gtk_widget_destroy(legend_page);
+	legend_page = legend_create_content();
+	gtk_notebook_insert_page(GTK_NOTEBOOK(map_notebook),
+				 legend_page, label, LEGEND_PAGE);
+	g_object_unref(label);
 }
 
 static GtkWidget *build_status_bar(void)
@@ -1171,10 +1203,21 @@ static void register_pixmaps(void)
 					    pioneers_pixmaps[idx], NULL);
 		if (g_file_test(filename, G_FILE_TEST_EXISTS)) {
 			GtkIconSource *source;
-			source = gtk_icon_source_new();
-			gtk_icon_source_set_filename(source, filename);
-			gtk_icon_set_add_source(icon, source);
-			gtk_icon_source_free(source);
+			GdkPixbuf *pixbuf;
+			GError *error = NULL;
+			pixbuf =
+			    gdk_pixbuf_new_from_file(filename, &error);
+			if (error != NULL) {
+				g_warning("Error loading pixmap %s\n",
+					  filename);
+				g_error_free(error);
+			} else {
+				source = gtk_icon_source_new();
+				gtk_icon_source_set_pixbuf(source, pixbuf);
+				g_object_unref(pixbuf);
+				gtk_icon_set_add_source(icon, source);
+				gtk_icon_source_free(source);
+			}
 		} else {
 			/* Missing pixmap */
 			g_warning(_("Pixmap not found: %s\n"), filename);
@@ -1195,7 +1238,7 @@ GtkWidget *gui_build_interface()
 	GtkWidget *menubar;
 	GtkActionGroup *action_group;
 	GtkAccelGroup *accel_group;
-	GError *error;
+	GError *error = NULL;
 	gchar *icon_file;
 
 	player_init();
