@@ -1,8 +1,8 @@
 /* Pioneers - Implementation of the excellent Settlers of Catan board game.
  *   Go buy a copy.
  *
- * Copyright (C) 1999 the Free Software Foundation
- * Copyright (C) 2003 Bas Wijnen <b.wijnen@phys.rug.nl>
+ * Copyright (C) 1999 Dave Cole
+ * Copyright (C) 2003 Bas Wijnen <shevek@fmf.nl>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 #include "config.h"
@@ -72,10 +72,10 @@ void name_create_dlg()
 	gtk_misc_set_alignment(GTK_MISC(lbl), 1, 0.5);
 
 	name_entry = gtk_entry_new();
-	gtk_entry_set_max_length(GTK_ENTRY(name_entry), 30);
+	gtk_entry_set_max_length(GTK_ENTRY(name_entry), MAX_NAME_LENGTH);
 	gtk_widget_show(name_entry);
 	gtk_box_pack_start(GTK_BOX(hbox), name_entry, TRUE, TRUE, 0);
-	gtk_entry_set_width_chars(GTK_ENTRY(name_entry), 30);
+	gtk_entry_set_width_chars(GTK_ENTRY(name_entry), MAX_NAME_LENGTH);
 	gtk_entry_set_text(GTK_ENTRY(name_entry), my_player_name());
 
 	gtk_entry_set_activates_default(GTK_ENTRY(name_entry), TRUE);
