@@ -1,8 +1,8 @@
 /* Pioneers - Implementation of the excellent Settlers of Catan board game.
  *   Go buy a copy.
  *
- * Copyright (C) 1999 the Free Software Foundation
- * Copyright (C) 2003 Bas Wijnen <b.wijnen@phys.rug.nl>
+ * Copyright (C) 1999 Dave Cole
+ * Copyright (C) 2003 Bas Wijnen <shevek@fmf.nl>
  * Copyright (C) 2004 Roland Clobus <rclobus@bigfoot.com>
  * 
  * This program is free software; you can redistribute it and/or modify
@@ -17,15 +17,18 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 #include "config.h"
 #include "frontend.h"
+#ifdef HAVE_LIBGNOME
 #include <libgnome/libgnome.h>
+#endif
 #include "common_gtk.h"
 #include "config-gnome.h"
 #include "theme.h"
+#include "histogram.h"
 
 static gboolean have_dlg = FALSE;
 static gboolean connectable = FALSE;
@@ -38,6 +41,7 @@ static gboolean quit_when_offline = FALSE;
 static const gchar *override_language = NULL;
 #endif
 
+#ifdef HAVE_LIBGNOME
 const struct poptOption options[] = {
 	/* Commandline option of client: hostname of the server */
 	{"server", 's', POPT_ARG_STRING, &server, 0, N_("Server Host"),
@@ -54,6 +58,7 @@ const struct poptOption options[] = {
 #endif
 	{NULL, '\0', 0, 0, 0, NULL, NULL}
 };
+#endif
 
 static void frontend_offline_start_connect_cb(void)
 {
@@ -137,13 +142,15 @@ void frontend_init(int argc, char **argv)
 
 	set_ui_driver(&GTK_Driver);
 
-	config_init("/pioneers/");
+	config_init("pioneers");
 
+#ifdef HAVE_LIBGNOME
 	gnome_program_init(PACKAGE, VERSION,
 			   LIBGNOME_MODULE,
 			   argc, argv,
 			   GNOME_PARAM_POPT_TABLE, options,
 			   GNOME_PARAM_APP_DATADIR, DATADIR, NULL);
+#endif
 
 	/* Initialize the widget set */
 	gtk_init(&argc, &argv);
@@ -162,6 +169,8 @@ void frontend_init(int argc, char **argv)
 	/* Create the application window
 	 */
 	themes_init();
+	settings_init();
+	histogram_init();
 	app = gui_build_interface();
 
 	callbacks.mainloop = &gtk_main;
