@@ -1,8 +1,8 @@
 /* Pioneers - Implementation of the excellent Settlers of Catan board game.
  *   Go buy a copy.
  *
- * Copyright (C) 1999 the Free Software Foundation
- * Copyright (C) 2003 Bas Wijnen <b.wijnen@phys.rug.nl>
+ * Copyright (C) 1999 Dave Cole
+ * Copyright (C) 2003 Bas Wijnen <shevek@fmf.nl>
  * Copyright (C) 2004 Roland Clobus <rclobus@bigfoot.com>
  * 
  * This program is free software; you can redistribute it and/or modify
@@ -17,13 +17,14 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 #include "config.h"
 #include "colors.h"
 #include "frontend.h"
 #include "log.h"
+#include "gtkbugs.h"
 
 static void player_show_connected_at_iter(gint player_num,
 					  gboolean connected,
@@ -499,29 +500,7 @@ GtkWidget *player_build_summary()
 							  NULL);
 	gtk_tree_view_column_set_sizing(column,
 					GTK_TREE_VIEW_COLUMN_GROW_ONLY);
-	/** @bug 2005-07-25 In Gtk+ 2.6 the pixbuf column is 
-	 *  one pixel too small, the focus_line_width is not used correctly.
-	 *  See also http://bugzilla.gnome.org/show_bug.cgi?id=147867
-	 */
-	if (gtk_major_version == 2
-	    && (gtk_minor_version >= 5 && gtk_minor_version <= 6)) {
-		gint horizontal_separator, focus_line_width, icon_width;
-
-		gtk_tree_view_column_set_sizing(column,
-						GTK_TREE_VIEW_COLUMN_FIXED);
-		gtk_widget_style_get(summary_widget,
-				     "horizontal_separator",
-				     &horizontal_separator,
-				     "focus-line-width", &focus_line_width,
-				     NULL);
-		gtk_icon_size_lookup(GTK_ICON_SIZE_MENU, &icon_width,
-				     NULL);
-		gtk_tree_view_column_set_fixed_width(column,
-						     icon_width +
-						     2 *
-						     horizontal_separator +
-						     focus_line_width);
-	}
+	set_pixbuf_tree_view_column_autogrow(summary_widget, column);
 	gtk_tree_view_append_column(GTK_TREE_VIEW(summary_widget), column);
 
 	column = gtk_tree_view_column_new_with_attributes("",
