@@ -1,8 +1,9 @@
 /* Pioneers - Implementation of the excellent Settlers of Catan board game.
  *   Go buy a copy.
  *
- * Copyright (C) 1999 the Free Software Foundation
- * Copyright (C) 2003 Bas Wijnen <b.wijnen@phys.rug.nl>
+ * Copyright (C) 1999 Dave Cole
+ * Copyright (C) 2003 Bas Wijnen <shevek@fmf.nl>
+ * Copyright (C) 2005 Roland Clobus <rclobus@bigfoot.com>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,11 +17,14 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 #include "config.h"
 #include "frontend.h"
+#include "gui.h"
+
+static GtkWidget *settings_dlg = NULL;
 
 enum { TYPE_NUM,
 	TYPE_BOOL,
@@ -34,13 +38,25 @@ static void add_setting_desc(GtkWidget * table, gint row, gint col,
 
 	label = gtk_label_new(desc);
 	gtk_widget_show(label);
-	gtk_table_attach(GTK_TABLE(table), label,
-			 col, col + 1, row, row + 1,
-			 (GtkAttachOptions) GTK_FILL,
-			 (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
+	gtk_table_attach(GTK_TABLE(table), label, col, col + 1, row,
+			 row + 1, GTK_FILL, GTK_EXPAND | GTK_FILL, 0, 0);
 	gtk_misc_set_alignment(GTK_MISC(label), 0, 0.5);
 }
 
+static void add_setting_desc_with_image(GtkWidget * table, gint row,
+					gint col, const gchar * desc,
+					const gchar * iconname)
+{
+	GtkWidget *icon;
+
+	icon = gtk_image_new_from_stock(iconname, GTK_ICON_SIZE_MENU);
+	gtk_widget_show(icon);
+	gtk_table_attach(GTK_TABLE(table), icon, col, col + 1, row,
+			 row + 1, GTK_FILL, GTK_FILL, 0, 0);
+
+	add_setting_desc(table, row, col + 1, desc);
+}
+
 static void add_setting_val(GtkWidget * table, gint row, gint col,
 			    gint type, gint int_val,
 			    const gchar * char_val, gboolean right_aligned)
@@ -76,49 +92,26 @@ static void add_setting_val(GtkWidget * table, gint row, gint col,
 	gtk_widget_show(label);
 	gtk_table_attach(GTK_TABLE(table), label,
 			 col, col + 1, row, row + 1,
-			 (GtkAttachOptions) GTK_FILL,
-			 (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
+			 GTK_FILL, GTK_EXPAND | GTK_FILL, 0, 0);
 	gtk_misc_set_alignment(GTK_MISC(label),
 			       (right_aligned ? 1.0 : 0.0), 0.5);
 }
 
-GtkWidget *settings_create_dlg()
+static GtkWidget *settings_create_content(void)
 {
 	const GameParams *game_params;
-	static GtkWidget *settings_dlg;
 	GtkWidget *dlg_vbox;
 	GtkWidget *alignment;
 	GtkWidget *vbox;
 	GtkWidget *hbox;
 	GtkWidget *table;
 	GtkWidget *label;
-	gchar sevens_desc[50];
-
-	if (settings_dlg != NULL)
-		return settings_dlg;
-
-	settings_dlg =
-	    gtk_dialog_new_with_buttons(_("Current Game Settings"),
-					GTK_WINDOW(app_window),
-					GTK_DIALOG_DESTROY_WITH_PARENT,
-					GTK_STOCK_CLOSE,
-					GTK_RESPONSE_CLOSE, NULL);
-	g_signal_connect(GTK_OBJECT(settings_dlg), "destroy",
-			 GTK_SIGNAL_FUNC(gtk_widget_destroyed),
-			 &settings_dlg);
-
-	dlg_vbox = GTK_DIALOG(settings_dlg)->vbox;
-	gtk_widget_show(dlg_vbox);
+	gchar *sevens_desc;
 
 	/* Create some space inside the dialog */
-	vbox = gtk_vbox_new(FALSE, 6);
-	gtk_container_set_border_width(GTK_CONTAINER(vbox), 6);
-	gtk_widget_show(vbox);
-	gtk_box_pack_start(GTK_BOX(dlg_vbox), vbox, FALSE, FALSE, 0);
-	dlg_vbox = vbox;
-
-	g_signal_connect(settings_dlg, "response",
-			 G_CALLBACK(gtk_widget_destroy), NULL);
+	dlg_vbox = gtk_vbox_new(FALSE, 6);
+	gtk_container_set_border_width(GTK_CONTAINER(dlg_vbox), 6);
+	gtk_widget_show(dlg_vbox);
 
 	game_params = get_game_params();
 	if (game_params == NULL) {
@@ -126,9 +119,8 @@ GtkWidget *settings_create_dlg()
 		gtk_box_pack_start(GTK_BOX(dlg_vbox), label, TRUE, TRUE,
 				   6);
 		gtk_widget_show(label);
-		gtk_widget_show(settings_dlg);
 
-		return settings_dlg;
+		return dlg_vbox;
 	}
 
 	label = gtk_label_new(NULL);
@@ -170,17 +162,18 @@ GtkWidget *settings_create_dlg()
 			NULL, FALSE);
 
 	if (game_params->sevens_rule == 0) {
-		strcpy(sevens_desc, _("Normal"));
+		sevens_desc = g_strdup(_("Normal"));
 	} else if (game_params->sevens_rule == 1) {
-		strcpy(sevens_desc, _("Reroll on 1st 2 turns"));
+		sevens_desc = g_strdup(_("Reroll on 1st 2 turns"));
 	} else if (game_params->sevens_rule == 2) {
-		strcpy(sevens_desc, _("Reroll all 7s"));
+		sevens_desc = g_strdup(_("Reroll all 7s"));
 	} else {
-		strcpy(sevens_desc, _("Unknown"));
+		sevens_desc = g_strdup(_("Unknown"));
 	}
 
 	add_setting_desc(table, 6, 0, _("Sevens Rule:"));
 	add_setting_val(table, 6, 1, TYPE_STRING, 0, sevens_desc, FALSE);
+	g_free(sevens_desc);
 
 	/* Double space, otherwise the columns are too close */
 	hbox = gtk_hbox_new(FALSE, 24);
@@ -203,30 +196,35 @@ GtkWidget *settings_create_dlg()
 	gtk_widget_show(alignment);
 	gtk_box_pack_start(GTK_BOX(vbox), alignment, FALSE, TRUE, 0);
 
-	table = gtk_table_new(5, 2, FALSE);
+	table = gtk_table_new(5, 3, FALSE);
 	gtk_widget_show(table);
 	gtk_container_add(GTK_CONTAINER(alignment), table);
 	gtk_table_set_row_spacings(GTK_TABLE(table), 3);
 	gtk_table_set_col_spacings(GTK_TABLE(table), 6);
 
-	add_setting_desc(table, 0, 0, _("Roads:"));
-	add_setting_val(table, 0, 1, TYPE_NUM,
+	add_setting_desc_with_image(table, 0, 0, _("Roads:"),
+				    PIONEERS_PIXMAP_ROAD);
+	add_setting_val(table, 0, 2, TYPE_NUM,
 			game_params->num_build_type[BUILD_ROAD], NULL,
 			TRUE);
-	add_setting_desc(table, 1, 0, _("Settlements:"));
-	add_setting_val(table, 1, 1, TYPE_NUM,
+	add_setting_desc_with_image(table, 1, 0, _("Settlements:"),
+				    PIONEERS_PIXMAP_SETTLEMENT);
+	add_setting_val(table, 1, 2, TYPE_NUM,
 			game_params->num_build_type[BUILD_SETTLEMENT],
 			NULL, TRUE);
-	add_setting_desc(table, 2, 0, _("Cities:"));
-	add_setting_val(table, 2, 1, TYPE_NUM,
+	add_setting_desc_with_image(table, 2, 0, _("Cities:"),
+				    PIONEERS_PIXMAP_CITY);
+	add_setting_val(table, 2, 2, TYPE_NUM,
 			game_params->num_build_type[BUILD_CITY], NULL,
 			TRUE);
-	add_setting_desc(table, 3, 0, _("Ships:"));
-	add_setting_val(table, 3, 1, TYPE_NUM,
+	add_setting_desc_with_image(table, 3, 0, _("Ships:"),
+				    PIONEERS_PIXMAP_SHIP);
+	add_setting_val(table, 3, 2, TYPE_NUM,
 			game_params->num_build_type[BUILD_SHIP], NULL,
 			TRUE);
-	add_setting_desc(table, 4, 0, _("Bridges:"));
-	add_setting_val(table, 4, 1, TYPE_NUM,
+	add_setting_desc_with_image(table, 4, 0, _("Bridges:"),
+				    PIONEERS_PIXMAP_BRIDGE);
+	add_setting_val(table, 4, 2, TYPE_NUM,
 			game_params->num_build_type[BUILD_BRIDGE], NULL,
 			TRUE);
 
@@ -292,7 +290,62 @@ GtkWidget *settings_create_dlg()
 			game_params->num_develop_type[DEVEL_SOLDIER], NULL,
 			TRUE);
 
+	return dlg_vbox;
+}
+
+static void settings_rules_changed(void)
+{
+	if (settings_dlg) {
+		GtkWidget *vbox;
+		GtkWidget *dlg_vbox;
+		GList *list;
+
+		dlg_vbox = GTK_DIALOG(settings_dlg)->vbox;
+		list = gtk_container_get_children(GTK_CONTAINER(dlg_vbox));
+
+		if (g_list_length(list) > 0)
+			gtk_widget_destroy(GTK_WIDGET(list->data));
+		g_list_free(list);
+
+		vbox = settings_create_content();
+		gtk_box_pack_start(GTK_BOX(dlg_vbox), vbox, FALSE, FALSE,
+				   0);
+	}
+}
+
+GtkWidget *settings_create_dlg(void)
+{
+	GtkWidget *dlg_vbox;
+	GtkWidget *vbox;
+
+	if (settings_dlg != NULL)
+		return settings_dlg;
+
+	settings_dlg =
+	    gtk_dialog_new_with_buttons(_("Current Game Settings"),
+					GTK_WINDOW(app_window),
+					GTK_DIALOG_DESTROY_WITH_PARENT,
+					GTK_STOCK_CLOSE,
+					GTK_RESPONSE_CLOSE, NULL);
+	g_signal_connect(GTK_OBJECT(settings_dlg), "destroy",
+			 GTK_SIGNAL_FUNC(gtk_widget_destroyed),
+			 &settings_dlg);
+
+	dlg_vbox = GTK_DIALOG(settings_dlg)->vbox;
+	gtk_widget_show(dlg_vbox);
+
+	vbox = settings_create_content();
+	gtk_box_pack_start(GTK_BOX(dlg_vbox), vbox, FALSE, FALSE, 0);
+
+	g_signal_connect(settings_dlg, "response",
+			 G_CALLBACK(gtk_widget_destroy), NULL);
+
 	gtk_widget_show(settings_dlg);
 
 	return settings_dlg;
 }
+
+void settings_init(void)
+{
+	gui_rules_register_callback(G_CALLBACK(settings_rules_changed));
+}
