@@ -1,8 +1,8 @@
 /* Pioneers - Implementation of the excellent Settlers of Catan board game.
  *   Go buy a copy.
  *
- * Copyright (C) 1999 the Free Software Foundation
- * Copyright (C) 2003 Bas Wijnen <b.wijnen@phys.rug.nl>
+ * Copyright (C) 1999 Dave Cole
+ * Copyright (C) 2003 Bas Wijnen <shevek@fmf.nl>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 #ifndef __game_h
@@ -39,6 +39,9 @@ typedef enum {
 #define NUM_DEVEL_TYPES (DEVEL_SOLDIER + 1)
 
 #define MAX_PLAYERS 8		/* maximum number of players supported */
+#define MAX_CHAT 496		/* maximum chat message size
+				 * (512 - strlen("player 0 chat \n") - 1) */
+#define MAX_NAME_LENGTH 30	/* maximum length for the name of a player */
 
 typedef enum {
 	VAR_DEFAULT,		/* plain out-of-the-box game */
