@@ -1,8 +1,8 @@
 /* Pioneers - Implementation of the excellent Settlers of Catan board game.
  *   Go buy a copy.
  *
- * Copyright (C) 1999 the Free Software Foundation
- * Copyright (C) 2003 Bas Wijnen <b.wijnen@phys.rug.nl>
+ * Copyright (C) 1999 Dave Cole
+ * Copyright (C) 2003 Bas Wijnen <shevek@fmf.nl>
  * Copyright (C) 2004 Roland Clobus <rclobus@bigfoot.com>
  * 
  * This program is free software; you can redistribute it and/or modify
@@ -17,7 +17,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 #include "config.h"
@@ -290,11 +290,12 @@ static void calc_edge_poly(const GuiMap * gmap, const Edge * edge,
 	g_assert(poly->num_points >= shape->num_points);
 	poly->num_points = shape->num_points;
 
-	/* Work out rotation - y axis is upside down, so rotate in
-	 * reverse direction
+	/* Determine the angle for the polygon:
+	 * Polygons on edges are rotated 0, 60 or 120 degrees CCW
+	 * Polygons without edges are rotated 90 degrees CCW
 	 */
-	theta = (edge != NULL) ? (2 * M_PI / 6.0) * edge->pos : M_PI / 2;
-	theta = 2 * M_PI - theta;
+	theta =
+	    2 * M_PI * (edge != NULL ? 1 - (edge->pos % 3) / 6.0 : -0.25);
 	cos_theta = cos(theta);
 	sin_theta = sin(theta);
 	scale = (2 * gmap->y_point) / 120.0;
@@ -322,6 +323,11 @@ static void calc_edge_poly(const GuiMap * gmap, const Edge * edge,
 	if (edge != NULL) {
 		gint x_offset, y_offset;
 
+		/* Recalculate the angle for the position of the edge */
+		theta = 2 * M_PI * (1 - edge->pos / 6.0);
+		cos_theta = cos(theta);
+		sin_theta = sin(theta);
+
 		calc_hex_pos(gmap, edge->x, edge->y, &x_offset, &y_offset);
 		x_offset += gmap->x_point * cos_theta;
 		y_offset += gmap->x_point * sin_theta;
@@ -1691,6 +1697,32 @@ void guimap_cursor_move(GuiMap * gmap, gint x, gint y,
 				}
 			}
 
+			/* When both a ship and a bridge can be built,
+			 * divide the edge in four segments.
+			 * The two segments near the nodes are for the 
+			 * bridge (the pillars).
+			 * The two segments in the middle are for the
+			 * ship (open sea).
+			 */
+			if (can_build_ship && can_build_bridge) {
+				MapElement node1, node2;
+				gint distanceNode, distanceEdge;
+				node1.node = element->edge->nodes[0];
+				node2.node = element->edge->nodes[1];
+				distanceNode =
+				    MIN(distance_cursor
+					(gmap, &node1, MAP_NODE, x, y),
+					distance_cursor(gmap, &node2,
+							MAP_NODE, x, y));
+				distanceEdge =
+				    distance_cursor(gmap, element,
+						    MAP_EDGE, x, y);
+				if (distanceNode < distanceEdge)
+					can_build_ship = FALSE;
+				else
+					can_build_bridge = FALSE;
+			}
+
 			can_build_edge = can_build_road || can_build_ship
 			    || can_build_bridge;
 			if (can_build_edge)
