@@ -1,8 +1,8 @@
 /* Pioneers - Implementation of the excellent Settlers of Catan board game.
  *   Go buy a copy.
  *
- * Copyright (C) 1999 the Free Software Foundation
- * Copyright (C) 2003 Bas Wijnen <b.wijnen@phys.rug.nl>
+ * Copyright (C) 1999 Dave Cole
+ * Copyright (C) 2003 Bas Wijnen <shevek@fmf.nl>
  * Copyright (C) 2005 Roland Clobus <rclobus@bigfoot.com>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -17,7 +17,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 #include "config.h"
@@ -138,6 +138,7 @@ static MapTheme default_theme = {
 
 static GList *theme_list = NULL;
 static MapTheme *current_theme = NULL;
+static GList *callback_list = NULL;
 
 static gboolean theme_initialize(MapTheme * t, const gchar * subdir);
 static struct tvars *getvar(char **p, const gchar * filename, int lno);
@@ -233,7 +234,12 @@ void themes_init(void)
 
 void theme_set_current(MapTheme * t)
 {
+	GList *list = callback_list;
 	current_theme = t;
+	while (list) {
+		G_CALLBACK(list->data) ();
+		list = g_list_next(list);
+	}
 }
 
 MapTheme *theme_get_current(void)
@@ -711,3 +717,8 @@ static MapTheme *theme_config_parse(const gchar * themename,
 	g_free(t);
 	return NULL;
 }
+
+void theme_register_callback(GCallback callback)
+{
+	callback_list = g_list_append(callback_list, callback);
+}
