@@ -1,8 +1,8 @@
 /* Pioneers - Implementation of the excellent Settlers of Catan board game.
  *   Go buy a copy.
  *
- * Copyright (C) 1999 the Free Software Foundation
- * Copyright (C) 2003 Bas Wijnen <b.wijnen@phys.rug.nl>
+ * Copyright (C) 1999 Dave Cole
+ * Copyright (C) 2003 Bas Wijnen <shevek@fmf.nl>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 #include "config.h"
@@ -432,7 +432,17 @@ void sm_vnformat(gchar * buff, gint len, const gchar * fmt, va_list ap)
 
 void sm_write(StateMachine * sm, const gchar * str)
 {
-	net_write(sm->ses, str);
+	if (sm->use_cache) {
+		/* Protect against strange/slow connects */
+		if (g_list_length(sm->cache) > 1000) {
+			net_write(sm->ses, "ERR connection too slow");
+			net_close_when_flushed(sm->ses);
+		} else {
+			sm->cache =
+			    g_list_append(sm->cache, g_strdup(str));
+		}
+	} else
+		net_write(sm->ses, str);
 }
 
 void sm_send(StateMachine * sm, const gchar * fmt, ...)
@@ -447,6 +457,53 @@ void sm_send(StateMachine * sm, const gchar * fmt, ...)
 	sm_vnformat(buff, sizeof(buff), fmt, ap);
 	va_end(ap);
 
+	sm_write(sm, buff);
+}
+
+void sm_set_use_cache(StateMachine * sm, gboolean use_cache)
+{
+	if (sm->use_cache == use_cache)
+		return;
+
+	if (!use_cache) {
+		/* The cache is turned off, send the delayed data */
+		GList *list = sm->cache;
+		while (list) {
+			gchar *data = list->data;
+			net_write(sm->ses, data);
+			list = g_list_remove(list, data);
+			g_free(data);
+		}
+		sm->cache = NULL;
+	} else {
+		/* Be sure that the cache is empty */
+		g_assert(!sm->cache);
+	}
+	sm->use_cache = use_cache;
+}
+
+StateMachine *sm_copy_as_uncached(const StateMachine * sm)
+{
+	StateMachine *copy;
+	copy = g_malloc(sizeof(*sm));
+	memcpy(copy, sm, sizeof(*sm));
+	copy->use_cache = FALSE;
+	copy->cache = NULL;
+	return copy;
+}
+
+void sm_send_uncached(StateMachine * sm, const gchar * fmt, ...)
+{
+	va_list ap;
+	gchar buff[512];
+
+	g_assert(sm->ses);
+	g_assert(sm->use_cache);
+
+	va_start(ap, fmt);
+	sm_vnformat(buff, sizeof(buff), fmt, ap);
+	va_end(ap);
+
 	net_write(sm->ses, buff);
 }
 
