@@ -1,8 +1,8 @@
 /* Pioneers - Implementation of the excellent Settlers of Catan board game.
  *   Go buy a copy.
  *
- * Copyright (C) 1999 the Free Software Foundation
- * Copyright (C) 2003 Bas Wijnen <b.wijnen@phys.rug.nl>
+ * Copyright (C) 1999 Dave Cole
+ * Copyright (C) 2003 Bas Wijnen <shevek@fmf.nl>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 #ifndef __state_h
@@ -138,6 +138,9 @@ struct StateMachine {
 	Session *ses;		/* network session feeding state machine */
 	gint use_count;		/* # functions is in use by */
 	gboolean is_dead;	/* is this machine waiting to be killed? */
+
+	gboolean use_cache;	/* cache the data that is sent */
+	GList *cache;		/* cache for the delayed data */
 };
 
 StateMachine *sm_new(gpointer user_data);
@@ -151,6 +154,20 @@ void sm_cancel_prefix(StateMachine * sm);
 void sm_vnformat(gchar * buff, gint len, const gchar * fmt, va_list ap);
 void sm_write(StateMachine * sm, const gchar * str);
 void sm_send(StateMachine * sm, const gchar * fmt, ...);
+/** Cache the messages that are sent.
+ * When the caching is turned off, all cached data is sent.
+ * @param sm The statemachine
+ * @param use_cache Turn the caching on/off
+ */
+void sm_set_use_cache(StateMachine * sm, gboolean use_cache);
+/** Send the data, even when caching is turned on */
+void sm_send_uncached(StateMachine * sm, const gchar * fmt, ...);
+/** Create a copy of the current statemachine.
+ * The current statemachine must be cached.
+ * The copy must be freed with g_free.
+ */
+StateMachine *sm_copy_as_uncached(const StateMachine * sm);
+
 void sm_goto(StateMachine * sm, StateFunc new_state);
 void sm_goto_noenter(StateMachine * sm, StateFunc new_state);
 void sm_push(StateMachine * sm, StateFunc new_state);
