@@ -2,7 +2,9 @@
 
 #include <string.h>
 
+#ifdef HAVE_LIBGNOME
 #include <libgnome/libgnome.h>
+#endif
 
 #include "aboutbox.h"
 #include "config-gnome.h"
@@ -16,6 +18,8 @@
 #include "theme.h"
 #include "colors.h"
 
+#define MAINICON_FILE "pioneers-editor.png"
+
 #define MAP_WIDTH 550		/* default map width */
 #define MAP_HEIGHT 400		/* default map height */
 
@@ -97,6 +101,7 @@ static void error_dialog(const char *fmt, ...)
 
 static void clear_hex(Hex * hex)
 {
+	g_return_if_fail(hex != NULL);
 	hex->terrain = LAST_TERRAIN;
 	hex->resource = NO_RESOURCE;
 	hex->chit_pos = -1;
@@ -336,7 +341,7 @@ static void post_change(gint * size, GtkWidget ** buttons, gint amt)
 {
 	*size += amt;
 	gtk_widget_set_sensitive(buttons[0], *size < MAP_SIZE);
-	gtk_widget_set_sensitive(buttons[1], *size > 2);
+	gtk_widget_set_sensitive(buttons[1], *size > 1);
 	fill_map(gmap->map);
 	scale_map(gmap);
 	guimap_display(gmap);
@@ -397,9 +402,9 @@ static GtkWidget *build_map(void)
 			 0);
 
 	build_map_resize(table, 0, 1, GTK_ORIENTATION_HORIZONTAL,
-			 hresize_buttons, G_CALLBACK(change_height));
+			 vresize_buttons, G_CALLBACK(change_height));
 	build_map_resize(table, 1, 0, GTK_ORIENTATION_VERTICAL,
-			 vresize_buttons, G_CALLBACK(change_width));
+			 hresize_buttons, G_CALLBACK(change_width));
 
 	return table;
 }
@@ -429,7 +434,7 @@ static gint select_terrain_cb(G_GNUC_UNUSED GtkWidget * menu,
 			    hex_in_direction(gmap->map, current_hex, i);
 			if (adjacent != NULL
 			    && adjacent->resource != NO_RESOURCE
-			    && adjacent->facing == 6 - i) {
+			    && adjacent->facing == (i + 3) % 6) {
 				adjacent->resource = NO_RESOURCE;
 				adjacent->facing = 0;
 				guimap_draw_hex(gmap, adjacent);
@@ -758,7 +763,7 @@ static GameParams *get_params(void)
 	return params;
 }
 
-static void load_game(const gchar * file)
+static void load_game(const gchar * file, gboolean is_reload)
 {
 	const gchar *gamefile;
 	GameParams *new_params;
@@ -776,7 +781,7 @@ static void load_game(const gchar * file)
 	}
 
 	if (file == NULL) {
-		free(new_params->title);
+		g_free(new_params->title);
 		new_params->title = g_strdup("Untitled");
 		map_free(new_params->map);
 		new_params->map = map_new();
@@ -797,7 +802,12 @@ static void load_game(const gchar * file)
 	if (open_filename != NULL)
 		g_free(open_filename);
 	open_filename = new_filename;
+	map_move_robber(gmap->map, -1, -1);
 	fill_map(gmap->map);
+	if (is_reload) {
+		scale_map(gmap);
+		guimap_display(gmap);
+	}
 }
 
 static void save_game(const gchar * file)
@@ -811,7 +821,7 @@ static void save_game(const gchar * file)
 
 static void new_game_menu_cb(void)
 {
-	load_game(NULL);
+	load_game(NULL, TRUE);
 }
 
 static void load_game_menu_cb(void)
@@ -832,7 +842,7 @@ static void load_game_menu_cb(void)
 		file =
 		    gtk_file_chooser_get_filename(GTK_FILE_CHOOSER
 						  (dialog));
-		load_game(file);
+		load_game(file, TRUE);
 		g_free(file);
 		scale_map(gmap);
 		guimap_display(gmap);
@@ -859,7 +869,10 @@ static void save_as_menu_cb(void)
 		    gtk_file_chooser_get_filename(GTK_FILE_CHOOSER
 						  (dialog));
 		save_game(file);
-		g_free(file);
+		if (open_filename == NULL)
+			open_filename = file;
+		else
+			g_free(file);
 	}
 	gtk_widget_destroy(dialog);
 }
@@ -921,6 +934,8 @@ static void exit_cb(void)
 	gtk_main_quit();
 }
 
+#ifdef HAVE_HELP
+/* Commented out, until the help is written
 static void contents_menu_cb(void)
 {
 	GtkWidget *dialog;
@@ -934,6 +949,8 @@ static void contents_menu_cb(void)
 	gtk_dialog_run(GTK_DIALOG(dialog));
 	gtk_widget_destroy(dialog);
 }
+*/
+#endif
 
 static void about_menu_cb(void)
 {
@@ -955,15 +972,20 @@ static GtkActionEntry entries[] = {
 	 N_("Open an existing game"), load_game_menu_cb},
 	{"Save", GTK_STOCK_SAVE, N_("_Save"), "<control>S",
 	 N_("Save game"), save_game_menu_cb},
-	{"SaveAs", GTK_STOCK_SAVE, N_("Save _As..."), "<control><shift>S",
+	{"SaveAs", GTK_STOCK_SAVE_AS, N_("Save _As..."),
+	 "<control><shift>S",
 	 N_("Save as"), save_as_menu_cb},
 	{"ChangeTitle", NULL, N_("_Change title"), "<control>T",
 	 N_("Change game title"), change_title_menu_cb},
 	{"Quit", GTK_STOCK_QUIT, N_("_Quit"), "<control>Q",
 	 N_("Quit"), exit_cb},
 
-	{"Contents", GTK_STOCK_HELP, N_("_Contents"), "F1",
-	 N_("Contents"), contents_menu_cb},
+#ifdef HAVE_HELP
+	/* Disable this item, until the help is written
+	   {"Contents", GTK_STOCK_HELP, N_("_Contents"), "F1",
+	   N_("Contents"), contents_menu_cb},
+	 */
+#endif
 	{"About", NULL, N_("_About Pioneers Editor"), NULL,
 	 N_("Information about Pioneers Editor"), about_menu_cb}
 };
@@ -983,8 +1005,12 @@ static const char *ui_description =
 "      <menuitem action='Quit'/>"
 "    </menu>"
 "    <menu action='HelpMenu'>"
+#ifdef HAVE_HELP
+/* Disable this menu item, until the help is written
 "      <menuitem action='Contents'/>"
 "      <separator/>"
+*/
+#endif
 "      <menuitem action='About'/>"
 "    </menu>"
 "  </menubar>"
@@ -1000,7 +1026,8 @@ int main(int argc, char *argv[])
 	GtkWidget *vbox;
 	GtkWidget *menubar;
 	GtkAccelGroup *accel_group;
-	GError *error;
+	GError *error = NULL;
+	gchar *icon_file;
 
 	if (argc > 1)
 		filename = argv[1];
@@ -1010,8 +1037,10 @@ int main(int argc, char *argv[])
 	default_game = g_build_filename(get_pioneers_dir(), "default.game",
 					NULL);
 
+#ifdef HAVE_LIBGNOME
 	gnome_program_init("pioneers-editor", VERSION, LIBGNOME_MODULE,
 			   argc, argv, GNOME_PARAM_POPT_TABLE, NULL, NULL);
+#endif
 
 	gtk_init(&argc, &argv);
 
@@ -1043,7 +1072,17 @@ int main(int argc, char *argv[])
 		return 1;
 	}
 
-	config_init("/pioneers-editor/");
+	config_init("pioneers-editor");
+
+	icon_file =
+	    g_build_filename(DATADIR, "pixmaps", MAINICON_FILE, NULL);
+	if (g_file_test(icon_file, G_FILE_TEST_EXISTS)) {
+		gtk_window_set_default_icon_from_file(icon_file, NULL);
+	} else {
+		/* Missing pixmap, main icon file */
+		g_warning(_("Pixmap not found: %s\n"), icon_file);
+	}
+	g_free(icon_file);
 
 	themes_init();
 	colors_init();
@@ -1068,7 +1107,7 @@ int main(int argc, char *argv[])
 	gtk_box_pack_start(GTK_BOX(vbox), menubar, FALSE, FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(vbox), notebook, TRUE, TRUE, 0);
 
-	load_game(filename);
+	load_game(filename, FALSE);
 	if (params == NULL)
 		return 1;
 
@@ -1076,5 +1115,6 @@ int main(int argc, char *argv[])
 
 	gtk_main();
 
+	config_finish();
 	return 0;
 }
