@@ -1,8 +1,8 @@
 /* Pioneers - Implementation of the excellent Settlers of Catan board game.
  *   Go buy a copy.
  *
- * Copyright (C) 1999 the Free Software Foundation
- * Copyright (C) 2003 Bas Wijnen <b.wijnen@phys.rug.nl>
+ * Copyright (C) 1999 Dave Cole
+ * Copyright (C) 2003 Bas Wijnen <shevek@fmf.nl>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 #include "config.h"
@@ -251,7 +251,7 @@ static void client_do_write(Client * client)
 			if (errno == EAGAIN)
 				break;
 			syslog(LOG_ERR, "writing socket: %s",
-			       strerror(errno));
+			       g_strerror(errno));
 			client_close(client);
 			return;
 		} else if (num == len) {
@@ -398,8 +398,9 @@ static void client_list_types(Client * client)
 
 static void client_list_capability(Client * client)
 {
-	if (can_create_games)
+	if (can_create_games) {
 		client_printf(client, "create games\n");
+	}
 	/** @todo RC 2005-01-30 Implement this in the metaserver */
 	if (FALSE)
 		client_printf(client, "send game settings\n");
@@ -431,7 +432,7 @@ static void client_create_new_server(Client * client, gchar * line)
 	GSpawnFlags spawn_flags = G_SPAWN_STDOUT_TO_DEV_NULL |
 	    G_SPAWN_STDERR_TO_DEV_NULL;
 	gchar *child_argv[32];
-	GError *error;
+	GError *error = NULL;
 
 	line += strspn(line, " \t");
 	terrain = line;
@@ -476,13 +477,13 @@ static void client_create_new_server(Client * client, gchar * line)
 	fd = socket(AF_INET, SOCK_STREAM, 0);
 	if (fd < 0) {
 		client_printf(client, "Creating socket failed: %s\n",
-			      strerror(errno));
+			      g_strerror(errno));
 		return;
 	}
 	if (setsockopt(fd, SOL_SOCKET, SO_REUSEADDR, &yes, sizeof(yes)) <
 	    0) {
 		client_printf(client, "Setting socket reuse failed: %s\n",
-			      strerror(errno));
+			      g_strerror(errno));
 		return;
 	}
 	sa.sin_family = AF_INET;
@@ -514,14 +515,14 @@ static void client_create_new_server(Client * client, gchar * line)
 	sa.sin_addr.s_addr = htonl(INADDR_LOOPBACK);
 	if (bind(fd, (struct sockaddr *) &sa, sizeof(sa)) < 0) {
 		client_printf(client, "Binding socket failed: %s\n",
-			      strerror(errno));
+			      g_strerror(errno));
 		return;
 	}
 	yes = sizeof(sa);
 	if (getsockname(fd, (struct sockaddr *) &sa, &yes) < 0) {
 		client_printf(client,
 			      "Getting socket address failed: %s\n",
-			      strerror(errno));
+			      g_strerror(errno));
 		return;
 	}
 	sprintf(port, "%d", sa.sin_port);
@@ -672,7 +673,8 @@ static void client_process_line(Client * client, gchar * line)
 			client->type = META_CLIENT;
 			client_list_types(client);
 			client->waiting_for_close = TRUE;
-		} else if (strncmp(line, "create ", 7) == 0) {
+		} else if (strncmp(line, "create ", 7) == 0
+			   && can_create_games) {
 			client->type = META_CLIENT;
 			client_create_new_server(client, line + 7);
 			client->waiting_for_close = TRUE;
@@ -750,7 +752,7 @@ static void client_do_read(Client * client)
 	if (num < 0) {
 		if (errno == EAGAIN)
 			return;
-		syslog(LOG_ERR, "reading socket: %s", strerror(errno));
+		syslog(LOG_ERR, "reading socket: %s", g_strerror(errno));
 		client_close(client);
 		return;
 	}
@@ -900,7 +902,7 @@ static void select_loop(void)
 				continue;
 			else {
 				syslog(LOG_ALERT, "could not select: %s",
-				       strerror(errno));
+				       g_strerror(errno));
 				exit(1);
 			}
 		}
@@ -958,7 +960,7 @@ static void convert_to_daemon(void)
 
 	pid = fork();
 	if (pid < 0) {
-		syslog(LOG_ALERT, "could not fork: %s", strerror(errno));
+		syslog(LOG_ALERT, "could not fork: %s", g_strerror(errno));
 		exit(1);
 	}
 	if (pid != 0)
@@ -970,12 +972,13 @@ static void convert_to_daemon(void)
 	/* Create a new session to become a process group leader
 	 */
 	if (setsid() < 0) {
-		syslog(LOG_ALERT, "could not setsid: %s", strerror(errno));
+		syslog(LOG_ALERT, "could not setsid: %s",
+		       g_strerror(errno));
 		exit(1);
 	}
 	if (chdir("/") < 0) {
 		syslog(LOG_ALERT, "could not chdir to /: %s",
-		       strerror(errno));
+		       g_strerror(errno));
 		exit(1);
 	}
 	umask(0);
@@ -1024,6 +1027,7 @@ int main(int argc, char *argv[])
 			break;
 		}
 
+	net_init();
 	openlog("pioneers-meta", LOG_PID, LOG_USER);
 	if (make_daemon)
 		convert_to_daemon();
@@ -1050,5 +1054,6 @@ int main(int argc, char *argv[])
 	syslog(LOG_INFO, "Pioneers meta server started.");
 	select_loop();
 
+	net_finish();
 	return 0;
 }
