@@ -1,8 +1,8 @@
 /* Pioneers - Implementation of the excellent Settlers of Catan board game.
  *   Go buy a copy.
  *
- * Copyright (C) 1999 the Free Software Foundation
- * Copyright (C) 2003 Bas Wijnen <b.wijnen@phys.rug.nl>
+ * Copyright (C) 1999 Dave Cole
+ * Copyright (C) 2003 Bas Wijnen <shevek@fmf.nl>
  * Copyright (C) 2004-2005 Roland Clobus <rclobus@bigfoot.com>
  * 
  * This program is free software; you can redistribute it and/or modify
@@ -17,11 +17,13 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 #include "config.h"
+#ifdef HAVE_LIBGNOME
 #include <libgnome/libgnome.h>
+#endif
 #include <ctype.h>
 #include <gtk/gtk.h>
 #include <string.h>
@@ -36,7 +38,7 @@
 #include "select-game.h"	/* Custom widget */
 #include "game-settings.h"	/* Custom widget */
 
-#define PIONEERS_ICON_FILE	"gnome-pioneers.png"
+#define MAINICON_FILE	"pioneers-server.png"
 
 static GtkWidget *game_frame;	/* the frame containing all settings regarding the game */
 static GtkWidget *select_game;	/* select game type */
@@ -55,6 +57,7 @@ static GtkTooltips *tooltips;	/* tooltips */
 
 static GtkListStore *store;	/* shows player connection status */
 
+
 static gboolean ui_enabled;	/* is the ui accessible? */
 static gchar *hostname;		/* reported hostname */
 static gchar *server_port = NULL;	/* port of the game */
@@ -287,10 +290,18 @@ static void gui_player_rename(void *data)
 		    player->name);
 }
 
+static gboolean everybody_left(G_GNUC_UNUSED gpointer data)
+{
+	if (server_stop())
+		gui_ui_enable(TRUE);
+	return FALSE;
+}
+
 static void gui_player_change(void *data)
 {
 	Game *game = data;
 	GList *current;
+	guint number_of_players = 0;
 
 	gtk_list_store_clear(store);
 	playerlist_inc_use_count(game);
@@ -301,6 +312,9 @@ static void gui_player_change(void *data)
 		gboolean isViewer;
 
 		isViewer = player_is_viewer(p->game, p->num);
+		if (!isViewer && !p->disconnected)
+			number_of_players++;
+
 		gtk_list_store_append(store, &iter);
 		gtk_list_store_set(store, &iter,
 				   PLAYER_COLUMN_NAME, p->name,
@@ -311,6 +325,9 @@ static void gui_player_change(void *data)
 				   PLAYER_COLUMN_ISVIEWER, isViewer, -1);
 	}
 	playerlist_dec_use_count(game);
+	if (number_of_players == 0 && game->is_game_over) {
+		g_timeout_add(100, everybody_left, NULL);
+	}
 }
 
 static void add_game_to_list(gpointer name,
@@ -743,6 +760,14 @@ static void help_about_cb(void)
 	aboutbox_display(_("The Pioneers Game Server"), authors);
 }
 
+void game_is_over(G_GNUC_UNUSED Game * game)
+{
+	/* Wait for all players to disconnect,
+	 * then enable the UI
+	 */
+	log_message(MSG_INFO, _("The game is over.\n"));
+}
+
 int main(int argc, char *argv[])
 {
 	gchar *icon_file;
@@ -752,7 +777,9 @@ int main(int argc, char *argv[])
 	GtkActionGroup *action_group;
 	GtkUIManager *ui_manager;
 	GtkAccelGroup *accel_group;
-	GError *error;
+	GError *error = NULL;
+
+	net_init();
 
 	/* set the UI driver to GTK_Driver, since we're using gtk */
 	set_ui_driver(&GTK_Driver);
@@ -766,6 +793,7 @@ int main(int argc, char *argv[])
 	/* Initialize frontend inspecific things */
 	server_init();
 
+#ifdef HAVE_LIBGNOME
 	/* @todo RC 2005-04-10 If the client does not need libgnomeui
 	 * anymore, perhaps the gnome_program_init call could be moved
 	 * to config-gnome.c, which would allow a GNOME-free application,
@@ -774,6 +802,7 @@ int main(int argc, char *argv[])
 	gnome_program_init("pioneers-server", VERSION,
 			   LIBGNOME_MODULE,
 			   argc, argv, GNOME_PARAM_POPT_TABLE, NULL, NULL);
+#endif
 
 	/* Initialize the widget set */
 	gtk_init(&argc, &argv);
@@ -811,10 +840,10 @@ int main(int argc, char *argv[])
 		return 1;
 	}
 
-	config_init("/pioneers-server/");
+	config_init("pioneers-server");
 
 	icon_file =
-	    g_build_filename(DATADIR, "pixmaps", PIONEERS_ICON_FILE, NULL);
+	    g_build_filename(DATADIR, "pixmaps", MAINICON_FILE, NULL);
 	if (g_file_test(icon_file, G_FILE_TEST_EXISTS)) {
 		gtk_window_set_default_icon_from_file(icon_file, NULL);
 	} else {
@@ -838,5 +867,7 @@ int main(int argc, char *argv[])
 
 	gtk_main();
 
+	config_finish();
+	net_finish();
 	return 0;
 }
