@@ -1,8 +1,8 @@
 /* Pioneers - Implementation of the excellent Settlers of Catan board game.
  *   Go buy a copy.
  *
- * Copyright (C) 1999 the Free Software Foundation
- * Copyright (C) 2003 Bas Wijnen <b.wijnen@phys.rug.nl>
+ * Copyright (C) 1999 Dave Cole
+ * Copyright (C) 2003 Bas Wijnen <shevek@fmf.nl>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 #include "config.h"
@@ -32,6 +32,10 @@ static gboolean mode_bad_version(Player * player, gint event);
 static gboolean mode_game_is_over(Player * player, gint event);
 static gboolean mode_global(Player * player, gint event);
 static gboolean mode_unhandled(Player * player, gint event);
+static void player_setup(Player * player, int playernum,
+			 const gchar * name, gboolean force_viewer);
+static Player *player_by_name(Game * game, char *name);
+
 
 static gint next_player_num(Game * game, gboolean force_viewer)
 {
@@ -101,13 +105,20 @@ static gboolean mode_global(Player * player, gint event)
 		return TRUE;
 	case SM_RECV:
 		if (sm_recv(sm, "chat %S", text, sizeof(text))) {
-			player_broadcast(player, PB_ALL, "chat %s\n",
-					 text);
+			if (strlen(text) > MAX_CHAT)
+				sm_send(sm, "ERR %s\n",
+					_("chat too long"));
+			else
+				player_broadcast(player, PB_ALL,
+						 "chat %s\n", text);
 			return TRUE;
 		}
 		if (sm_recv(sm, "name %S", text, sizeof(text))) {
 			if (text[0] == 0)
 				sm_send(sm, "ERR invalid-name\n");
+			else if (strlen(text) > MAX_NAME_LENGTH)
+				sm_send(sm, "ERR %s\n",
+					_("name too long"));
 			else
 				player_set_name(player, text);
 			return TRUE;
@@ -230,6 +241,11 @@ Player *player_new(Game * game, int fd, gchar * location)
 		return NULL;
 	}
 
+	/* Cache messages of the game in progress until all intial 
+	 * messages have been sent
+	 */
+	sm_set_use_cache(sm, TRUE);
+
 	player->game = game;
 	player->location = g_strdup(location);
 	player->devel = deck_new(game->params);
@@ -288,11 +304,10 @@ static void player_set_name_real(Player * player, gchar * name,
 	driver->player_change(game);
 }
 
-void player_setup(Player * player, int playernum, gchar * name,
-		  gboolean force_viewer)
+static void player_setup(Player * player, int playernum,
+			 const gchar * name, gboolean force_viewer)
 {
-	gchar nm[100];
-	gchar *namep;
+	gchar nm[MAX_NAME_LENGTH + 1];
 	Game *game = player->game;
 	StateMachine *sm = player->sm;
 	Player *other;
@@ -316,27 +331,22 @@ void player_setup(Player * player, int playernum, gchar * name,
 	/* give the player her new name */
 	if (name == NULL) {
 		if (player_is_viewer(game, player->num)) {
-			gint num = 0;
+			gint num = 1;
 			do {
-				sprintf(nm, "Viewer %d", num++);
+				sprintf(nm, _("Viewer %d"), num++);
 			} while (player_by_name(game, nm) != NULL);
-			namep = nm;
 		} else {
-			sprintf(nm, "Player %d", player->num);
-			namep = nm;
+			sprintf(nm, _("Player %d"), player->num);
 		}
-	} else
-		namep = name;
+	} else {
+		strncpy(nm, name, G_N_ELEMENTS(nm));
+		nm[G_N_ELEMENTS(nm) - 1] = '\0';
+	}
 
 	/* if the new name exists, try padding it with underscores */
-	other = player_by_name(game, namep);
+	other = player_by_name(game, nm);
 	if (other != player && other != NULL) {
 		gint i;
-		/* put the name in the buffer, so it is editable */
-		if (namep != nm) {
-			strncpy(nm, namep, sizeof(nm));
-			namep = nm;
-		}
 		/* add underscores until the name is unique */
 		for (i = strlen(nm); i < G_N_ELEMENTS(nm) - 1; ++i) {
 			if (player_by_name(game, nm) == NULL)
@@ -344,17 +354,27 @@ void player_setup(Player * player, int playernum, gchar * name,
 			nm[i] = '_';
 			nm[i + 1] = 0;
 		}
-		if (i == G_N_ELEMENTS(nm) - 1) {
-			/* This should never happen */
-			/* use the connection name */
-			strncpy(nm, player->name, sizeof(nm));
+		/* Adding underscores was not enough to make the name unique.
+		 * While staying within the maximum name length,
+		 * create numbers at the end of the name.
+		 * Repeat until an unique name has been found.
+		 */
+		while (player_by_name(game, nm)) {
+			gint digit = 10;
+			i = G_N_ELEMENTS(nm) - 1;
+			while (digit == 10 && i > 0) {
+				/* Digit will be: 0..10 */
+				--i;
+				digit = g_ascii_digit_value(nm[i]) + 1;
+				nm[i] = '0' + digit % 10;
+			}
 		}
 	}
 	/* copy the (possibly new) name to dynamic memory */
 	/* don't broadcast the name.  This is done by mode_pre_game, after
 	 * telling the user how many players are in the game.
 	 * That should keep things easier for the client. */
-	player_set_name_real(player, namep, FALSE);
+	player_set_name_real(player, nm, FALSE);
 
 	/* add the info in the output device */
 	driver->player_added(player);
@@ -490,16 +510,23 @@ void player_revive(Player * newp, char *name)
 	/* Don't use the old player's name */
 
 	/* copy over all the data from p */
+	g_assert(newp->build_list == NULL);
 	newp->build_list = p->build_list;
 	p->build_list = NULL;	/* prevent deletion */
+
 	memcpy(newp->prev_assets, p->prev_assets,
 	       sizeof(newp->prev_assets));
 	memcpy(newp->assets, p->assets, sizeof(newp->assets));
 	newp->gold = p->gold;
+	/* take over the development deck */
+	deck_free(newp->devel);
 	newp->devel = p->devel;
-	p->devel = NULL;	/* prevent deletion */
+	p->devel = NULL;
+
+	g_assert(newp->points == NULL);
 	newp->points = p->points;
 	p->points = NULL;	/* prevent deletion */
+
 	newp->discard_num = p->discard_num;
 	newp->num_roads = p->num_roads;
 	newp->num_bridges = p->num_bridges;
@@ -602,7 +629,7 @@ static gboolean mode_bad_version(Player * player, gint event)
 	sm_state_name(sm, "mode_bad_version");
 	switch (event) {
 	case SM_ENTER:
-		sm_send(sm, "ERR sorry, version conflict\n");
+		sm_send_uncached(sm, "ERR sorry, version conflict\n");
 		break;
 	}
 	return FALSE;
@@ -634,7 +661,7 @@ static gboolean mode_check_version(Player * player, gint event)
 	sm_state_name(sm, "mode_check_version");
 	switch (event) {
 	case SM_ENTER:
-		sm_send(sm, "version report\n");
+		sm_send_uncached(sm, "version report\n");
 		break;
 
 	case SM_RECV:
@@ -672,7 +699,7 @@ static gboolean mode_check_status(Player * player, gint event)
 	sm_state_name(sm, "mode_check_status");
 	switch (event) {
 	case SM_ENTER:
-		sm_send(sm, "status report\n");
+		sm_send_uncached(sm, "status report\n");
 		break;
 
 	case SM_RECV:
@@ -749,7 +776,7 @@ GList *player_next_real(GList * last)
 	return list;
 }
 
-Player *player_by_name(Game * game, char *name)
+static Player *player_by_name(Game * game, char *name)
 {
 	GList *list;
 
