@@ -1,8 +1,8 @@
 /* Pioneers - Implementation of the excellent Settlers of Catan board game.
  *   Go buy a copy.
  *
- * Copyright (C) 1999 the Free Software Foundation
- * Copyright (C) 2003 Bas Wijnen <b.wijnen@phys.rug.nl>
+ * Copyright (C) 1999 Dave Cole
+ * Copyright (C) 2003 Bas Wijnen <shevek@fmf.nl>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 #include "config.h"
@@ -149,7 +149,7 @@ gint new_computer_player(const gchar * server, const gchar * port,
 			 gboolean want_chat)
 {
 	gchar *child_argv[8];
-	GError *error;
+	GError *error = NULL;
 	gint ret = 0;
 	gint n = 0;
 	gint i;
@@ -240,6 +240,8 @@ gboolean server_startup(GameParams * params, const gchar * hostname,
 
 gboolean server_stop()
 {
+	if (curr_game == NULL)
+		return FALSE;
 	game_free(curr_game);
 	curr_game = NULL;
 	return TRUE;
@@ -484,3 +486,13 @@ void server_init(void)
 	 * when the game is over. */
 	signal(SIGPIPE, handle_sigpipe);
 }
+
+void server_cleanup_static_data(void)
+{
+	GSList *games = _game_list;
+	while (games) {
+		params_free(games->data);
+		games = g_slist_next(games);
+	}
+	g_slist_free(_game_list);
+}
