@@ -1,8 +1,8 @@
 /* Pioneers - Implementation of the excellent Settlers of Catan board game.
  *   Go buy a copy.
  *
- * Copyright (C) 1999 the Free Software Foundation
- * Copyright (C) 2003 Bas Wijnen <b.wijnen@phys.rug.nl>
+ * Copyright (C) 1999 Dave Cole
+ * Copyright (C) 2003 Bas Wijnen <shevek@fmf.nl>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 #ifndef __server_h
@@ -149,9 +149,6 @@ typedef enum {
 	PB_OTHERS
 } BroadcastType;
 Player *player_new(Game * game, int fd, gchar * location);
-void player_setup(Player * player, int playernum, gchar * name, gboolean
-		  force_viewer);
-Player *player_by_name(Game * game, char *name);
 Player *player_by_num(Game * game, gint num);
 void player_set_name(Player * player, gchar * name);
 Player *player_none(Game * game);
@@ -173,7 +170,7 @@ gboolean player_is_viewer(Game * game, gint player_num);
 /* pregame.c */
 gboolean mode_pre_game(Player * player, gint event);
 gboolean mode_setup(Player * player, gint event);
-gboolean send_gameinfo(Map * map, Hex * hex, Player * sm);
+gboolean send_gameinfo(Map * map, Hex * hex, StateMachine * sm);
 void next_setup_player(Game * game);
 
 /* resource.c */
@@ -207,6 +204,7 @@ gboolean server_stop(void);
 gboolean server_is_running(void);
 gint accept_connection(gint in_fd, gchar ** location);
 gint open_listen_socket(const gchar * port);
+void server_cleanup_static_data(void);
 
 /**** game list control functions ****/
 GameParams *game_list_find_item(const gchar * title);
@@ -229,7 +227,7 @@ gboolean start_server(const gchar * hostname,
 
 /* initialize the server */
 void server_init(void);
-
+void game_is_over(Game * game);
 
 /* trade.c */
 void trade_perform_maritime(Player * player,
