@@ -1,8 +1,8 @@
 /* Pioneers - Implementation of the excellent Settlers of Catan board game.
  *   Go buy a copy.
  *
- * Copyright (C) 1999 the Free Software Foundation
- * Copyright (C) 2003 Bas Wijnen <b.wijnen@phys.rug.nl>
+ * Copyright (C) 1999 Dave Cole
+ * Copyright (C) 2003 Bas Wijnen <shevek@fmf.nl>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 #include "config.h"
@@ -313,11 +313,6 @@ static gboolean distribute_resources(G_GNUC_UNUSED Map * map, Hex * hex,
 	return FALSE;
 }
 
-static gboolean exit_func(G_GNUC_UNUSED gpointer data)
-{
-	exit(0);
-}
-
 void check_victory(Player * player)
 {
 	Game *game = player->game;
@@ -345,11 +340,7 @@ void check_victory(Player * player)
 					    (StateFunc) mode_idle);
 		}
 
-		/* quit in ten seconds if configured */
-		if (game->params->quit_when_done) {
-			g_timeout_add(10 * 1000, &exit_func, NULL);
-		}
-
+		game_is_over(game);
 	}
 }
 
